var core = require('@raam/core');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var propsWithoutUndefined = function propsWithoutUndefined(obj) {
  return Object.keys(obj).reduce(function (acc, key) {
    if (obj[key] !== undefined) acc[key] = obj[key];
    return acc;
  }, {});
};

var flexVariants = {
  vStack: {
    gap: "1rem",
    flexDirection: "column",
    flexWrap: "nowrap"
  },
  hStack: {
    gap: "1rem",
    flexDirection: "row",
    flexWrap: "nowrap"
  },
  wrap: {
    gap: "1rem",
    alignItems: "center",
    flexDirection: "row",
    flexWrap: "wrap",
    justifyContent: "flex-start"
  }
};

var flexParent = function flexParent(_ref) {
  var flexGap = _ref.gap,
      withoutBaseStyles = _ref.withoutBaseStyles,
      withoutElementStyles = _ref.withoutElementStyles,
      props = _objectWithoutPropertiesLoose(_ref, ["gap", "withoutBaseStyles", "withoutElementStyles"]);

  return _extends({}, withoutBaseStyles && core.reset, !withoutElementStyles && {
    /**
     * `ul`
     * Override browser defaults
     */
    paddingLeft: 0
  }, {
    display: "flex",
    margin: "var(" + core.FLEX_GAP_CSS_VARS.FLEX_GAP_OFFSET + ", initial)"
  }, core.stylePropsToCSS(_extends({
    flexGap: flexGap
  }, props)));
};

var flexChild = function flexChild(_ref2) {
  var _ref2$flex = _ref2.flex,
      flex = _ref2$flex === void 0 ? "0 0 auto" : _ref2$flex,
      flexBasis = _ref2.flexBasis,
      flexGrow = _ref2.flexGrow,
      flexShrink = _ref2.flexShrink,
      _ref2$index = _ref2.index,
      index = _ref2$index === void 0 ? 1 : _ref2$index,
      withoutBaseStyles = _ref2.withoutBaseStyles,
      withoutElementStyles = _ref2.withoutElementStyles,
      theme = _ref2.theme;
  return _extends({}, !withoutBaseStyles && core.reset, !withoutElementStyles && {
    /**
     * `li`
     * Ensure any list-items are rendered without bullets.
     * Adding a zero-width space in the content to prevent VoiceOver disable.
     */
    listStyleType: "none",
    "&:before": {
      position: "absolute",
      content: '"\\200B"'
    }
  }, {
    marginTop: "var(" + core.FLEX_GAP_CSS_VARS.FLEX_GAP + ", " + (index > 0 ? "var(" + core.FLEX_GAP_CSS_VARS.FLEX_GAP_TOP + ", initial)" : "initial") + ")",
    marginRight: "var(" + core.FLEX_GAP_CSS_VARS.FLEX_GAP + ", initial)",
    marginBottom: "var(" + core.FLEX_GAP_CSS_VARS.FLEX_GAP + ", initial)",
    marginLeft: "var(" + core.FLEX_GAP_CSS_VARS.FLEX_GAP + ", " + (index > 0 ? "var(" + core.FLEX_GAP_CSS_VARS.FLEX_GAP_LEFT + ", initial)" : "initial") + ")"
  }, core.stylePropsToCSS({
    flex: flex,
    flexBasis: flexBasis,
    flexGrow: flexGrow,
    flexShrink: flexShrink,
    theme: theme
  }));
};

var useFlex = function useFlex(props) {
  var variant = (props == null ? void 0 : props.variant) || "hStack"; // @TODO Support Responsive Variants

  var propsWithVariant = variant ? _extends({}, flexVariants[variant], props && propsWithoutUndefined(props)) : propsWithoutUndefined(props);
  return {
    parent: function parent() {
      return flexParent(_extends({}, propsWithVariant));
    },
    child: function child(childProps) {
      return flexChild(childProps ? _extends({}, childProps, propsWithVariant) : propsWithVariant);
    }
  };
};

exports.useFlex = useFlex;
//# sourceMappingURL=index.js.map
